<?php
/**
 * Theme functions and definitions
 *
 * @package yuma_masonry
 */  

if ( ! function_exists( 'yuma_masonry_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function yuma_masonry_enqueue_styles() {
		wp_enqueue_style( 'yuma-parent-style', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'yuma-masonry-style', get_stylesheet_directory_uri() . '/style.css', array('yuma-parent-style') );
	}
endif;
add_action( 'wp_enqueue_scripts', 'yuma_masonry_enqueue_styles' );

if ( ! function_exists( 'yuma_masonry_theme_defaults' ) ) :
    /**
     * Customize theme defaults.
     *
     * @since 1.0.0
     *
     * @param array $defaults Theme defaults.
     * @param array Custom theme defaults.
     */
    function yuma_masonry_theme_defaults( $defaults ) {
        // theme color
        $defaults['theme_color'] = 'custom';
        $defaults['color_primary'] = '#0a0e14';
        $defaults['color_secondary'] = '#c1a28b';

        // typography
        $defaults['body_font_family'] = json_encode(array('font' => 'Red Hat Display') );
        $defaults['heading_font_family'] = json_encode(array('font' => 'Bitter') );
        $defaults['section_title_font_family'] = json_encode(array('font' => 'Bitter') );
        $defaults['home_title_font_family'] = json_encode(array('font' => 'Bitter') );
        $defaults['page_title_font_family'] = json_encode(array('font' => 'Bitter') );
        $defaults['entry_title_font_family'] = json_encode(array('font' => 'Bitter') );
        $defaults['entry_meta_font_family'] = json_encode(array('font' => 'Red Hat Display') );

        // topbar section
        $defaults['topbar_font_size'] = 16;
        $defaults['topbar_height'] = 60;
        $defaults['topbar_border_height'] = 1;

        // header section
        $defaults['header_height'] = 250;
        $defaults['header_site_details_layout'] = 'vertical-site-details';
        $defaults['header_left_element'] = '';
        $defaults['header_right_element'] = '';
        $defaults['header_border_height'] = 1;
        
        // latest blog
        $defaults['latest_blog_title'] = '';
        $defaults['blog_column_type'] = 'column-3';
        $defaults['blog_layout'] = 'image-focus-dark';
        $defaults['blog_image_size'] = 'yuma-post-thumbnail';
        $defaults['filter_blog_posts'] = 'none';
        
        // single post
        $defaults['single_header_image_size'] = 'full-width-size';
        $defaults['show_single_breadcrumb'] = false;

        // page post
        $defaults['page_header_image_size'] = 'full-width-size';
        $defaults['show_page_breadcrumb'] = false;

        // footer section
        $defaults['footer_font_size'] = 16;
        $defaults['footer_padding'] = 30;
                
        return $defaults;
    }
endif;
add_filter( 'yuma_default_theme_options', 'yuma_masonry_theme_defaults', 99 );

if ( ! function_exists( 'yuma_masonry_set_theme_mods' ) ) :
    /**
     * Set theme mod.
     */
    function yuma_masonry_set_theme_mods() {
        $theme_mod = get_theme_mod( 'yuma_theme_options' );
        if ( isset( $theme_mod ) && $theme_mod ) {
            return;
        }

        $yuma_theme_options = array( 
            // topbar section
            'topbar_left_element' => 'topbar_menu',
            'topbar_right_element' => 'social_menu,off_canvas_bar,search',
            'topbar_bg_color' => '#ffffff',
            'topbar_elements_color' => '#0a0e14',
            'topbar_dropdown_icon_color' => '#0a0e14',
            'topbar_border_color' => 'rgba(0,0,0,0.1)',
            
            // header section
            'header_center_element' => 'site_details',
            'header_border_color' => 'rgba(0,0,0,0.1)',

            // footer widget area
            'footer_bg_color' => '#f6f6f7',
            'footer_elements_color' => '#0a0e14',
            'footer_widget_bg_color' => '#f6f6f7',
            'footer_widget_title_color' => '#0a0e14',
            'footer_widget_elements_color' => '#0a0e14',
        );
        set_theme_mod( 'yuma_theme_options', $yuma_theme_options );
    }
endif;
add_action( 'after_setup_theme', 'yuma_masonry_set_theme_mods' );
